@@ -1,10 +1,12 @@
+import warnings
 from hepi.input import Order
-from .. import Input, Result,   get_output_dir
+from .. import Input, Result, get_output_dir
 import re
 from uncertainties import ufloat_fromstr
 from string import Template
 import pkgutil
 import os
+import shutil
 
 
 class ResumminoResult(Result):
@@ -20,7 +22,9 @@ class ResumminoResult(Result):
         VNLO_PLUS_P_PLUS_K (double): VNLO+P+K result.
         RNLO_PLUS_VNLO_PLUS_P_PLUS_K (double): RNLO+VNLO+P+K result.
     """
-    def __init__(self, lo, nlo, nlo_plus_nll, vnlo, p_plus_k, rnlog, rnloq):
+
+    def __init__(self, lo, nlo, nlo_plus_nll, annlo_plus_nnll, vnlo, p_plus_k,
+                 rnlog, rnloq):
         """
         Sets given and computes dependent ``Attributes``.
 
@@ -33,7 +37,7 @@ class ResumminoResult(Result):
             rnlog (:obj:`double`): corresponds to :attr:`RNLOG`.
             rnloq (:obj:`double`): corresponds to :attr:`RNLOQ`.
         """
-        Result.__init__(self, lo, nlo, nlo_plus_nll)
+        Result.__init__(self, lo, nlo, nlo_plus_nll, annlo_plus_nnll)
         self.VNLO = vnlo
         self.P_PLUS_K = p_plus_k
         self.RNLOG = rnlog
@@ -43,17 +47,16 @@ class ResumminoResult(Result):
         else:
             self.VNLO_PLUS_P_PLUS_K = None
         if not (rnlog is None or rnloq is None):
-            self.RNLO = rnlog+rnloq
+            self.RNLO = rnlog + rnloq
         else:
             self.RNLO = None
-        if not ( self.RNLO is None or self.VNLO_PLUS_P_PLUS_K is None):
+        if not (self.RNLO is None or self.VNLO_PLUS_P_PLUS_K is None):
             self.RNLO_PLUS_VNLO_PLUS_P_PLUS_K = self.RNLO + self.VNLO_PLUS_P_PLUS_K
         else:
             self.RNLO_PLUS_VNLO_PLUS_P_PLUS_K = None
 
-# TODO move functions to results
 
-def is_valid(file:str,p:Input,d) -> bool:
+def is_valid(file: str, p: Input, d) -> bool:
     """
     Verifies that an file is a complete output.
 
@@ -66,19 +69,17 @@ def is_valid(file:str,p:Input,d) -> bool:
         bool : True if `file` could be parsed.
     """
     order = p.order
-    data = pkgutil.get_data(__name__, "plot_template.in").decode(
-                'utf-8')
+    data = pkgutil.get_data(__name__, "plot_template.in").decode('utf-8')
     src = Template(data)
     result = src.substitute(d)
     sname = d['slha']
-    with open(file,mode='r') as f:
+    with open(file, mode='r') as f:
         with open(get_output_dir() + sname, 'r') as sf:
             if not f.read().startswith(result + "\n\n" + sf.read()):
-                #warnings.warn("Possible hash collision in " + file + " -> deleted",RuntimeWarning)
-                os.remove(file)
-                #exit(1)
-                #return False
-                print("HASH COLLIDED", file)
+                warnings.warn(
+                    "Possible hash collision in " + file + " -> moved to " +
+                    file + ".old", RuntimeWarning)
+                shutil.move(file, file + ".old")
                 return False
     res = parse_single(file)
     if res.LO is not None and order is Order.LO:
@@ -87,11 +88,13 @@ def is_valid(file:str,p:Input,d) -> bool:
         return True
     if res.LO is not None and res.NLO is not None and res.NLO_PLUS_NLL is not None and order is Order.NLO_PLUS_NLL:
         return True
-    print("RESTART" ,res.LO, res.NLO,res.NLO_PLUS_NLL, file)
+    if res.LO is not None and res.NLO is not None and res.aNNLO_PLUS_NNLL is not None and order is Order.aNNLO_PLUS_NNLL:
+        return True
+    print("RESTART", res.LO, res.NLO, res.NLO_PLUS_NLL, file)
     return False
 
 
-def parse_single(file : str) -> ResumminoResult:
+def parse_single(file: str) -> ResumminoResult:
     """
     Extracts LO, NLO and NLO+NLL from Resummino output file.
 
@@ -102,10 +105,12 @@ def parse_single(file : str) -> ResumminoResult:
         :class:`ResumminoResult` : If a value is not found in the file None is used.
 
     """
+    # TODO aNNLO+ NNLL support?
     # TODO generalize units like RS
     lo_pattern = re.compile(r'^LO = \((.*)\) pb')
     nlo_pattern = re.compile(r'^NLO = \((.*)\) pb')
     nll_pattern = re.compile(r'^NLO\+NLL = \((.*)\) pb')
+    nnll_pattern = re.compile(r'^aNNLO\+NNLL = \((.*)\) pb')
 
     vnlo_pattern = re.compile(r'^vNLO = \((.*)\) pb')
     ppk_pattern = re.compile(r'^P\+K = \((.*)\) pb')
@@ -115,6 +120,7 @@ def parse_single(file : str) -> ResumminoResult:
     lo_result = None
     nlo_result = None
     nll_result = None
+    nnll_result = None
 
     vnlo_result = None
     ppk_result = None
@@ -131,6 +137,9 @@ def parse_single(file : str) -> ResumminoResult:
             tmp = nll_pattern.search(line)
             if tmp is not None:
                 nll_result = ufloat_fromstr(tmp.group(1).replace("+-", "+/-"))
+            tmp = nnll_pattern.search(line)
+            if tmp is not None:
+                nnll_result = ufloat_fromstr(tmp.group(1).replace("+-", "+/-"))
             tmp = vnlo_pattern.search(line)
             if tmp is not None:
                 vnlo_result = ufloat_fromstr(tmp.group(1).replace("+-", "+/-"))
@@ -145,4 +154,5 @@ def parse_single(file : str) -> ResumminoResult:
             if tmp is not None:
                 rnloq_result = ufloat_fromstr(
                     tmp.group(1).replace("+-", "+/-"))
-    return ResumminoResult(lo_result, nlo_result, nll_result, vnlo_result, ppk_result, rnlog_result, rnloq_result)
+    return ResumminoResult(lo_result, nlo_result, nll_result, nnll_result,
+                           vnlo_result, ppk_result, rnlog_result, rnloq_result)
